The **SmartWatch Gestures Dataset** has been collected to evaluate several
gesture recognition algorithms for interacting with mobile applications using
arm gestures.

Eight different users performed twenty repetitions of twenty different gestures,
for a total of 3200 sequences. Each sequence contains acceleration data from the
3-axis accelerometer of a first generation Sony SmartWatch™, as well as
timestamps from the different clock sources available on an Android device. The
smartwatch was worn on the user's right wrist. The gestures have been manually
segmented by the users performing them by tapping the smartwatch screen at the
beginning and at the end of every repetition.
